atomate.vasp.analysis package — atomate 0.9.2 documentation

# atomate.vasp.analysis package

## Submodules

## atomate.vasp.analysis.phonopy module

`atomate.vasp.analysis.phonopy.` `get_phonopy_gibbs`(energies, volumes, force_constants, structure, t_min, t_step, t_max, mesh, eos, pressure=0)

  Compute QHA gibbs free energy using the phonopy interface.

  Args:

    energies (list): volumes (list): force_constants (list): structure (Structure): t_min (float): min temperature t_step (float): temperature step t_max (float): max temperature mesh (list/tuple): reciprocal space density eos (str): equation of state used for fitting the energies and the volumes.

    > options supported by phonopy: vinet, murnaghan, birch_murnaghan

    pressure (float): in GPa, optional.

  Returns:

    (numpy.ndarray, numpy.ndarray): Gibbs free energy, Temperature

`atomate.vasp.analysis.phonopy.` `get_phonopy_qha`(energies, volumes, force_constants, structure, t_min, t_step, t_max, mesh, eos, pressure=0)

  Return phonopy QHA interface.

  Args:

    energies (list): volumes (list): force_constants (list): structure (Structure): t_min (float): min temperature t_step (float): temperature step t_max (float): max temperature mesh (list/tuple): reciprocal space density eos (str): equation of state used for fitting the energies and the volumes.

    > options supported by phonopy: vinet, murnaghan, birch_murnaghan

    pressure (float): in GPa, optional.

  Returns:

    PhonopyQHA

`atomate.vasp.analysis.phonopy.` `get_phonopy_thermal_expansion`(energies, volumes, force_constants, structure, t_min, t_step, t_max, mesh, eos, pressure=0)

  Compute QHA thermal expansion coefficient using the phonopy interface.

  Args:

    energies (list): volumes (list): force_constants (list): structure (Structure): t_min (float): min temperature t_step (float): temperature step t_max (float): max temperature mesh (list/tuple): reciprocal space density eos (str): equation of state used for fitting the energies and the volumes.

    > options supported by phonopy: vinet, murnaghan, birch_murnaghan

    pressure (float): in GPa, optional.

  Returns:

    (numpy.ndarray, numpy.ndarray): thermal expansion coefficient, Temperature

## Module contents